@@ -4,6 +4,7 @@ Module defining constants and enumerate types used in the package
 import functools
 import itertools as it
 import mimetypes
+import re
 import warnings
 from enum import Enum, EnumMeta
 
@@ -85,6 +86,7 @@ class CRSMeta(EnumMeta):
         - 4326
         - 'EPSG:3857'
         - {'init': 32633}
+        - geojson['crs']['properties']['name'] string (urn:ogc:def:crs:...)
         - pyproj.CRS(32743)
         """
         if isinstance(value, dict) and 'init' in value:
@@ -101,6 +103,9 @@ class CRSMeta(EnumMeta):
         if isinstance(value, int):
             return str(value)
         if isinstance(value, str):
+            if 'urn:ogc:def:crs' in value.lower():
+                crs_template = re.compile(r'urn:ogc:def:crs:.+::(?P<code>.+)', re.IGNORECASE)
+                value = crs_template.match(value).group("code")
             if value.upper() == 'CRS84':
                 return '4326'
             return value.lower().strip('epsg: ')
@@ -237,22 +242,19 @@ class CRS(Enum, metaclass=CRSMeta):
 class CustomUrlParam(Enum):
     """ Enum class to represent supported custom url parameters of OGC services
 
-    Supported parameters are `SHOWLOGO`, `ATMFILTER`, `EVALSCRIPT`, `EVALSCRIPTURL`, `PREVIEW`, `QUALITY`, `UPSAMPLING`,
-    `DOWNSAMPLING`, `TRANSPARENT`, `BGCOLOR` and `GEOMETRY`.
+    Supported parameters are `SHOWLOGO`, `EVALSCRIPT`, `EVALSCRIPTURL`, `PREVIEW`, `QUALITY`, `UPSAMPLING`,
+    `DOWNSAMPLING`, `GEOMETRY` and `WARNINGS`.
 
     See http://sentinel-hub.com/develop/documentation/api/custom-url-parameters and
     https://www.sentinel-hub.com/develop/documentation/api/ogc_api/wms-parameters for more information.
     """
     SHOWLOGO = 'ShowLogo'
-    ATMFILTER = 'AtmFilter'
     EVALSCRIPT = 'EvalScript'
     EVALSCRIPTURL = 'EvalScriptUrl'
     PREVIEW = 'Preview'
     QUALITY = 'Quality'
     UPSAMPLING = 'Upsampling'
     DOWNSAMPLING = 'Downsampling'
-    TRANSPARENT = 'Transparent'
-    BGCOLOR = 'BgColor'
     GEOMETRY = 'Geometry'
     MINQA = 'MinQA'
 
@@ -290,15 +292,12 @@ class HistogramType(Enum):
 
 
 class MimeType(Enum):
-    """ Enum class to represent supported image file formats
+    """ Enum class to represent supported file formats
 
     Supported file formats are TIFF 8-bit, TIFF 16-bit, TIFF 32-bit float, PNG, JPEG, JPEG2000, JSON, CSV, ZIP, HDF5,
     XML, GML, RAW
     """
     TIFF = 'tiff'
-    TIFF_d8 = 'tiff;depth=8'
-    TIFF_d16 = 'tiff;depth=16'  # This is the same as TIFF
-    TIFF_d32f = 'tiff;depth=32f'
     PNG = 'png'
     JPG = 'jpg'
     JP2 = 'jp2'
@@ -320,9 +319,6 @@ class MimeType(Enum):
         :returns: A file extension string
         :rtype: str
         """
-        if self.is_tiff_format():
-            return MimeType.TIFF.value
-
         return self.value
 
     @staticmethod
@@ -341,6 +337,7 @@ class MimeType(Enum):
             return {
                 'tif': MimeType.TIFF,
                 'jpeg': MimeType.JPG,
+                'jpg': MimeType.JPG,
                 'hdf5': MimeType.HDF,
                 'h5': MimeType.HDF
             }[mime_type_str]
@@ -365,8 +362,7 @@ class MimeType(Enum):
         :return: `True` if file is in image format, `False` otherwise
         :rtype: bool
         """
-        return self in frozenset([MimeType.TIFF, MimeType.TIFF_d8, MimeType.TIFF_d16, MimeType.TIFF_d32f, MimeType.PNG,
-                                  MimeType.JP2, MimeType.JPG])
+        return self in frozenset([MimeType.TIFF, MimeType.PNG, MimeType.JP2, MimeType.JPG])
 
     def is_api_format(self):
         """ Checks if mime type is supported by Sentinel Hub API
@@ -376,18 +372,6 @@ class MimeType(Enum):
         """
         return self in frozenset([MimeType.JPG, MimeType.PNG, MimeType.TIFF, MimeType.JSON])
 
-    def is_tiff_format(self):
-        """ Checks whether file format is a TIFF image format
-
-        Example: ``MimeType.TIFF.is_tiff_format()`` or ``MimeType.is_tiff_format(MimeType.TIFF)``
-
-        :param self: File format
-        :type self: MimeType
-        :return: `True` if file is in image format, `False` otherwise
-        :rtype: bool
-        """
-        return self in frozenset([MimeType.TIFF, MimeType.TIFF_d8, MimeType.TIFF_d16, MimeType.TIFF_d32f])
-
     @classmethod
     def has_value(cls, value):
         """ Tests whether MimeType contains a constant defined with string ``value``
@@ -409,37 +393,15 @@ class MimeType(Enum):
             return 'application/x-tar'
         if self is MimeType.JSON:
             return 'application/json'
-        if self in [MimeType.TIFF_d8, MimeType.TIFF_d16, MimeType.TIFF_d32f]:
-            return 'image/{}'.format(self.value)
         if self is MimeType.JP2:
             return 'image/jpeg2000'
         if self is MimeType.RAW:
             return self.value
         return mimetypes.types_map['.' + self.value]
 
-    def get_sample_type(self):
-        """ Returns sampleType used in Sentinel-Hub evalscripts.
-
-        :return: sampleType
-        :rtype: str
-        :raises: ValueError
-        """
-        try:
-            return {
-                MimeType.TIFF: 'INT16',
-                MimeType.TIFF_d8: 'INT8',
-                MimeType.TIFF_d16: 'INT16',
-                MimeType.TIFF_d32f: 'FLOAT32'
-            }[self]
-        except KeyError as exception:
-            raise ValueError('Type {} is not supported by this method'.format(self)) from exception
-
     def get_expected_max_value(self):
         """ Returns max value of image `MimeType` format and raises an error if it is not an image format
 
-        Note: For `MimeType.TIFF_d32f` it will return ``1.0`` as that is expected maximum for an image even though it
-        could be higher.
-
         :return: A maximum value of specified image format
         :rtype: int or float
         :raises: ValueError
@@ -447,9 +409,6 @@ class MimeType(Enum):
         try:
             return {
                 MimeType.TIFF: 65535,
-                MimeType.TIFF_d8: 255,
-                MimeType.TIFF_d16: 65535,
-                MimeType.TIFF_d32f: 1.0,
                 MimeType.PNG: 255,
                 MimeType.JPG: 255,
                 MimeType.JP2: 10000
