@@ -21,7 +21,7 @@ class _CollectionType:
     SENTINEL1 = 'Sentinel-1'
     LANDSAT8 = 'Landsat 8'
     MODIS = 'MODIS'
-    DEM = 'Mapzen DEM'
+    DEM = 'DEM'
     BYOC = 'BYOC'
     BATCH = 'BATCH'
     LANDSAT5 = 'Landsat 5'
@@ -154,6 +154,7 @@ class DataCollectionDefinition:
     collection_id: str = None
     is_timeless: bool = False
     has_cloud_coverage: bool = False
+    dem_instance: str = None
 
     def __post_init__(self):
         """ In case a list of bands has been given this makes sure to cast it into a tuple
@@ -257,11 +258,20 @@ class DataCollection(Enum, metaclass=_DataCollectionMeta):
 
     DEM = DataCollectionDefinition(
         api_id='DEM',
-        wfs_id='DSS4',
         collection_type=_CollectionType.DEM,
         bands=_Bands.DEM,
         is_timeless=True
     )
+    DEM_MAPZEN = DEM.derive(
+        dem_instance='MAPZEN'
+    )
+    DEM_COPERNICUS_30 = DEM.derive(
+        dem_instance='COPERNICUS_30'
+    )
+    DEM_COPERNICUS_90 = DEM.derive(
+        dem_instance='COPERNICUS_90'
+    )
+
     MODIS = DataCollectionDefinition(
         api_id='MODIS',
         catalog_id='modis',
@@ -333,7 +343,8 @@ class DataCollection(Enum, metaclass=_DataCollectionMeta):
     @classmethod
     def define(cls, name, *, api_id=None, catalog_id=None, wfs_id=None, service_url=None, collection_type=None,
                sensor_type=None, processing_level=None, swath_mode=None, polarization=None, resolution=None,
-               orbit_direction=None, timeliness=None, bands=None, collection_id=None, is_timeless=False):
+               orbit_direction=None, timeliness=None, bands=None, collection_id=None, is_timeless=False,
+               dem_instance=None):
         """ Define a new data collection
 
         Note that all parameters, except `name` are optional. If a data collection definition won't be used for a
@@ -372,6 +383,9 @@ class DataCollection(Enum, metaclass=_DataCollectionMeta):
         :type collection_id: str or None
         :param is_timeless: `True` if a data collection can be filtered by time dimension and `False` otherwise
         :type is_timeless: bool
+        :param dem_instance: one of the options listed in
+                `DEM documentation <https://docs.sentinel-hub.com/api/latest/data/dem/#deminstance>`__
+        :type dem_instance: str or None
         :return: A new data collection
         :rtype: DataCollection
         """
@@ -390,7 +404,8 @@ class DataCollection(Enum, metaclass=_DataCollectionMeta):
             timeliness=timeliness,
             bands=bands,
             collection_id=collection_id,
-            is_timeless=is_timeless
+            is_timeless=is_timeless,
+            dem_instance=dem_instance
         )
         cls._try_add_data_collection(name, definition)
         return cls(definition)
@@ -429,7 +444,10 @@ class DataCollection(Enum, metaclass=_DataCollectionMeta):
 
         if is_name_defined:
             raise ValueError(f"Data collection name '{name}' is already taken by another data collection")
-        raise ValueError('Data collection definition is already taken by a data collection with a different name')
+
+        existing_collection = cls._value2member_map_[definition]
+        raise ValueError(f'Data collection definition is already taken by {existing_collection}. Two different '
+                         f'DataCollection enums cannot have the same definition.')
 
     @classmethod
     def define_byoc(cls, collection_id, **params):
